@@ -29,7 +29,8 @@ class PrivateKeyTestCase(base.KeyTestCase):
                                       self.bit_length,
                                       self.encoded,
                                       self.name,
-                                      self.created)
+                                      self.created,
+                                      consumers=self.consumers)
 
     def setUp(self):
         self.algorithm = 'RSA'
@@ -37,6 +38,9 @@ class PrivateKeyTestCase(base.KeyTestCase):
         self.encoded = bytes(utils.get_private_key_der())
         self.name = 'my key'
         self.created = 1448088699
+        self.consumers = [{'service': 'service_test',
+                           'resource_type': 'type_test',
+                           'resource_id': 'id_test'}]
 
         super(PrivateKeyTestCase, self).setUp()
 
@@ -69,13 +73,17 @@ class PrivateKeyTestCase(base.KeyTestCase):
     def test_get_created(self):
         self.assertEqual(self.created, self.key.created)
 
+    def test_get_consumers(self):
+        self.assertEqual(self.consumers, self.key.consumers)
+
     def test_get_created_none(self):
         created = None
         key = private_key.PrivateKey(self.algorithm,
                                      self.bit_length,
                                      self.encoded,
                                      self.name,
-                                     created)
+                                     created,
+                                     consumers=self.consumers)
 
         self.assertEqual(created, key.created)
 
@@ -88,7 +96,8 @@ class PrivateKeyTestCase(base.KeyTestCase):
 
         other_key = private_key.PrivateKey(self.algorithm,
                                            self.bit_length,
-                                           self.encoded)
+                                           self.encoded,
+                                           consumers=self.consumers)
         self.assertTrue(self.key == other_key)
         self.assertFalse(self.key is other_key)
 
@@ -100,14 +109,16 @@ class PrivateKeyTestCase(base.KeyTestCase):
         other_key = private_key.PrivateKey('DSA',
                                            self.bit_length,
                                            self.encoded,
-                                           self.name)
+                                           self.name,
+                                           consumers=self.consumers)
         self.assertTrue(self.key != other_key)
 
     def test___ne___bit_length(self):
         other_key = private_key.PrivateKey(self.algorithm,
                                            4096,
                                            self.encoded,
-                                           self.name)
+                                           self.name,
+                                           consumers=self.consumers)
         self.assertTrue(self.key != other_key)
 
     def test___ne___encoded(self):
@@ -115,9 +126,22 @@ class PrivateKeyTestCase(base.KeyTestCase):
         other_key = private_key.PrivateKey(self.algorithm,
                                            self.bit_length,
                                            different_encoded,
-                                           self.name)
+                                           self.name,
+                                           consumers=self.consumers)
         self.assertTrue(self.key != other_key)
 
+    def test___ne___consumers(self):
+        different_consumers = [{'service': 'other_service',
+                                'resource_type': 'other_type',
+                                'resource_id': 'other_id'}]
+        other_key = private_key.PrivateKey(self.algorithm,
+                                           self.bit_length,
+                                           self.encoded,
+                                           self.name,
+                                           consumers=different_consumers)
+
+        self.assertTrue(self.key is not other_key)
+
     def test_to_and_from_dict(self):
         other = objects.from_dict(self.key.to_dict())
         self.assertEqual(self.key, other)
